@@ -405,7 +405,7 @@ proceed? }
           changelog_arr_current = IO.readlines(fn)
           changelog_arr_next=changelog_arr_current.each.map do |line|
             if line =~/^\*\s+sisu_[0-9]+\.[0-9]+\.[0-9]+(?:_pre_rel)?\.orig\.tar\.xz \(Open commit window: [0-9]{4}-[0-9]{2}-[0-9]{2}; Pre-Release\)\)$/
-              "** sisu_#{vi[:version]}.orig.tar.xz " \
+              "* sisu_#{vi[:version]}.orig.tar.xz " \
               + "(#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})\n"
             else line
             end
@@ -437,7 +437,7 @@ proceed? }
     def self.changelog_header_pre_release(vi)
       vn=version_number(vi)
       <<-WOK
-* #{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release))
+* sisu_#{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release))
   http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
       WOK
     end
@@ -616,9 +616,9 @@ end
   def self.build(fn)
     system(%{ gem build #{fn}.gemspec })
   end
-  def self.install(fn)
+  def self.install(vn)
     system(%{
-      sudo gem install --local --no-document --verbose #{fn}.gem
+      sudo gem install --local --no-document --verbose sisu-#{vn}.gem
     })
   end
   module Current
@@ -651,8 +651,13 @@ end
     def self.build_stable
       Gemspecs.build(filename)
     end
-    def self.install_stable
-      Gemspecs.install(filename_stable)
+    def self.install_stable(version=:version_standard)
+      vi=Version_info::Current.setting_stable
+      vn=((version==:version_git) \
+      && (Version_info.version_number_use(vi) != vi[:version_number])) \
+      ? (Version_info.version_number_use(vi))
+      : (vi[:version_number])
+      Gemspecs.install(vn)
     end
   end
 end
